﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;

using MindFusion.Charting;
using MindFusion.Charting.WinForms;
using MindFusion.Charting.Components;
using MindFusion.Drawing;

using Color = System.Drawing.Color;


namespace GroupLabels
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			// create sample data
			var series = new ObservableCollection<Series>();
			for (int i = 0; i < 4; i++)
			{
				if (i == 0)
				{
					series.Add(new BarSeries(
						new double[] { 20, 60, 40, 55 },
						new string[] { "Acer", "Biostar", "Foxconn", "Supermicro" },
						new string[] { "", "", "", "" }));
				}
				if (i == 1)
				{
					series.Add(new BarSeries(
					   new double[] { 30, 70, 65, 19 },
					   new string[] { "Biostar", "Intel", "Nvidia", "VIA Technologies" },
					   new string[] { "", "", "", "" }));
				}
				if (i == 2)
				{
					series.Add(new BarSeries(
					   new double[] { 22, 44, 33, 66 },
					   new string[] { "Foxconn", "Nvidia", "Marvell", "NexGen" },
					   new string[] { "", "", "", "" }));
				}
				if (i == 3)
				{
					series.Add(new BarSeries(
					   new double[] { 12, 45, 77, 90 },
					   new string[] { "Supermicro", "VIA Technologies", "NexGen", "Toshiba" },
					   new string[] { "", "", "", "" }));
				}
			}

			// create labels data
			var annotations = new ObservableCollection<Series>();
			annotations.Add(new BarSeries(
				new double[] { 0, 0, 0, 0 },
				new string[] { "", "", "", "" },
				new string[] { "", "", "", "" },
				new string[] { "Motherboards", "Chipsets", "CPU", "HDD" }));


			var mainGrid = new GridPanel();
			mainGrid.HorizontalAlignment = LayoutAlignment.Stretch;
			mainGrid.VerticalAlignment = LayoutAlignment.Stretch;
			mainGrid.Columns.Add(new GridColumn());
			mainGrid.Rows.Add(new GridRow());
			barChart.RootPanel.Children.Add(mainGrid);

			// add plot
			var plot1 = new Plot2D();
			plot1.GridColumn = 1;
			plot1.GridRow = 0;
			plot1.VerticalScroll = false;
			plot1.XAxis = new Axis();
			plot1.YAxis = new Axis { MinValue = 0, MaxValue = 100 };
			mainGrid.Children.Add(plot1);

			// add renderer
			var barRenderer = new BarRenderer(series);
			barRenderer.LabelBrush = new SolidBrush(Color.FromArgb(200, 200, 200));
			barRenderer.LabelFontSize = 10;
			barRenderer.LabelFontStyle = System.Drawing.FontStyle.Italic;
			plot1.SeriesRenderers.Add(barRenderer);

			// add labels renderer
			var annotationRenderer = new AnnotationRenderer(annotations);
			plot1.SeriesRenderers.Add(annotationRenderer);

			// create axes
			var yAxis = new YAxisRenderer(plot1.YAxis, plot1.XAxis);
			yAxis.PlotLeftSide = true;
			yAxis.GridColumn = 0;
			yAxis.LabelsSource = plot1;
			mainGrid.Children.Add(yAxis);

			var xAxis = new XAxisRenderer(plot1.XAxis);
			xAxis.GridRow = 1;
			xAxis.GridColumn = 1;
			xAxis.LabelsSource = plot1;
			xAxis.ShowCoordinates = false;
			xAxis.LabelFontStyle = System.Drawing.FontStyle.Underline;
			mainGrid.Children.Add(xAxis);

			// styles
			plot1.GridType = GridType.Crossed;
			plot1.XAxis.Title = "";
			plot1.YAxis.Title = "";
			plot1.GridColor1 = Color.Black;
			plot1.GridColor1 = Color.White;
			barChart.BackColor = Color.FromArgb(70, 70, 70);
			barChart.Theme.CommonSeriesFills = GetFills();
			barChart.Theme.AxisStroke = barChart.Theme.AxisLabelsBrush = new SolidBrush(Color.White);
			barChart.Theme.UniformSeriesStroke = new SolidBrush(Color.White);
			barChart.Theme.HighlightStroke = new SolidBrush(Color.FromArgb(70, 70, 70));
			barChart.Theme.HighlightStrokeThickness = 1;
			barChart.Theme.PlotBackground = new LinearGradientBrush(Color.Black, Color.White);
		}

		private List<Brush> GetFills()
		{
			List<Brush> fills = new List<Brush>();

			fills.Add( new LinearGradientBrush(Color.FromArgb(224, 233, 233), Color.FromArgb(91, 121, 165)));
			fills.Add( new LinearGradientBrush(Color.FromArgb(102, 154, 204), Color.FromArgb(0, 52, 102)));
			fills.Add( new LinearGradientBrush(Color.FromArgb(192, 192, 192), Color.FromArgb(45, 57, 86)));
			fills.Add( new LinearGradientBrush(Color.FromArgb(186, 0, 0), Color.FromArgb(220, 0, 0)));


			return fills;
		}
	}
}